"""
Python module generated from Java source file com.google.thirdparty.publicsuffix.TrieParser

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Joiner
from com.google.common.collect import ImmutableMap
from com.google.thirdparty.publicsuffix import *
from java.util import Deque
from typing import Any, Callable, Iterable, Tuple


class TrieParser:
    """
    Parser for a map of reversed domain names stored as a serialized radix tree.
    """


