"""
Python module generated from Java source file com.google.common.annotations.J2ktIncompatible

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import *
from typing import Any, Callable, Iterable, Tuple


class J2ktIncompatible:
    """
    The presence of this annotation on an API indicates that the method may *not* be used with
    J2kt.

    Since
    - 32.0.0
    """


