"""
Python module generated from Java source file com.google.common.io.Java8Compatibility

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from typing import Any, Callable, Iterable, Tuple


class Java8Compatibility:
    """
    Wrappers around Buffer methods that are covariantly overridden in Java 9+. See
    https://github.com/google/guava/issues/3990
    """


