"""
Python module generated from Java source file org.bukkit.scoreboard.Criterias

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class Criterias:
    """
    Criteria names which trigger an objective to be modified by actions in-game

    Deprecated
    - use the constants declared in Criteria instead
    """

    HEALTH = "health"
    PLAYER_KILLS = "playerKillCount"
    TOTAL_KILLS = "totalKillCount"
    DEATHS = "deathCount"
