"""
Python module generated from Java source file org.bukkit.event.world.WorldInitEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import World
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class WorldInitEvent(WorldEvent):
    """
    Called when a World is initializing.
    
    To get every world it is recommended to add following to the plugin.yml.
    ```load: STARTUP```
    """

    def __init__(self, world: "World"):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...
