"""
Python module generated from Java source file net.md_5.bungee.api.chat.Keybinds

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class Keybinds:
    """
    All keybind values supported by vanilla Minecraft.
    
    Values may be removed if they are no longer supported.

    See
    - KeybindComponent
    """

    JUMP = "key.jump"
    SNEAK = "key.sneak"
    SPRINT = "key.sprint"
    LEFT = "key.left"
    RIGHT = "key.right"
    BACK = "key.back"
    FORWARD = "key.forward"
    ATTACK = "key.attack"
    PICK_ITEM = "key.pickItem"
    USE = "key.use"
    DROP = "key.drop"
    HOTBAR_1 = "key.hotbar.1"
    HOTBAR_2 = "key.hotbar.2"
    HOTBAR_3 = "key.hotbar.3"
    HOTBAR_4 = "key.hotbar.4"
    HOTBAR_5 = "key.hotbar.5"
    HOTBAR_6 = "key.hotbar.6"
    HOTBAR_7 = "key.hotbar.7"
    HOTBAR_8 = "key.hotbar.8"
    HOTBAR_9 = "key.hotbar.9"
    INVENTORY = "key.inventory"
    SWAP_HANDS = "key.swapHands"
    LOAD_TOOLBAR_ACTIVATOR = "key.loadToolbarActivator"
    SAVE_TOOLBAR_ACTIVATOR = "key.saveToolbarActivator"
    PLAYERLIST = "key.playerlist"
    CHAT = "key.chat"
    COMMAND = "key.command"
    SOCIAL_INTERACTIONS = "key.socialInteractions"
    ADVANCEMENTS = "key.advancements"
    SPECTATOR_OUTLINES = "key.spectatorOutlines"
    SCREENSHOT = "key.screenshot"
    SMOOTH_CAMERA = "key.smoothCamera"
    FULLSCREEN = "key.fullscreen"
    TOGGLE_PERSPECTIVE = "key.togglePerspective"
