from .CrafterView import CrafterView
from .BeaconView import BeaconView
from .StonecutterView import StonecutterView
from .FurnaceView import FurnaceView
from .MerchantView import MerchantView
from .LecternView import LecternView
from .BrewingStandView import BrewingStandView
from .EnchantmentView import EnchantmentView
from .AnvilView import AnvilView
from .LoomView import LoomView