from .Reference import Reference
from .ReferenceQueue import ReferenceQueue
from .WeakReference import WeakReference
from .SoftReference import SoftReference
from .PhantomReference import PhantomReference