"""
Python module generated from Java source file java.io.FileNotFoundException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class FileNotFoundException(IOException):

    def __init__(self):
        """
        Constructs a `FileNotFoundException` with
        `null` as its error detail message.
        """
        ...


    def __init__(self, s: str):
        """
        Constructs a `FileNotFoundException` with the
        specified detail message. The string `s` can be
        retrieved later by the
        java.lang.Throwable.getMessage
        method of class `java.lang.Throwable`.

        Arguments
        - s: the detail message.
        """
        ...
