"""
Python module generated from Java source file com.google.common.collect.EmptyImmutableListMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class EmptyImmutableListMultimap(ImmutableListMultimap):
    """
    Implementation of ImmutableListMultimap with no entries.

    Author(s)
    - Jared Levy
    """

    def asMap(self) -> "ImmutableMap"["Object", Iterable["Object"]]:
        ...
