"""
Python module generated from Java source file org.bukkit.entity.Vehicle

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class Vehicle(Entity):
    """
    Represents a vehicle entity.
    """

    def getVelocity(self) -> "Vector":
        """
        Gets the vehicle's velocity.

        Returns
        - velocity vector
        """
        ...


    def setVelocity(self, vel: "Vector") -> None:
        """
        Sets the vehicle's velocity in meters per tick.

        Arguments
        - vel: velocity vector
        """
        ...
