"""
Python module generated from Java source file org.bukkit.SkullType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class SkullType(Enum):
    """
    Represents the different types of skulls.

    Deprecated
    - check Material instead
    """

    SKELETON = 0
    WITHER = 1
    ZOMBIE = 2
    PLAYER = 3
    CREEPER = 4
    DRAGON = 5
    PIGLIN = 6
