"""
Python module generated from Java source file org.bukkit.material.PistonExtensionMaterial

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class PistonExtensionMaterial(MaterialData, Attachable):
    """
    Material data for the piston extension block

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        ...


    def getFacing(self) -> "BlockFace":
        ...


    def isSticky(self) -> bool:
        """
        Checks if this piston extension is sticky, and returns True if so

        Returns
        - True if this piston is "sticky", or False
        """
        ...


    def setSticky(self, sticky: bool) -> None:
        """
        Sets whether or not this extension is sticky

        Arguments
        - sticky: True if sticky, otherwise False
        """
        ...


    def getAttachedFace(self) -> "BlockFace":
        ...


    def clone(self) -> "PistonExtensionMaterial":
        ...
