"""
Python module generated from Java source file java.util.EventListener

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class EventListener:
    """
    A tagging interface that all event listener interfaces must extend.

    Since
    - 1.1
    """


