"""
Python module generated from Java source file com.google.common.util.concurrent.Internal

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from java.time import Duration
from typing import Any, Callable, Iterable, Tuple


class Internal:
    """
    This class is for `com.google.common.util.concurrent` use only!
    """


