"""
Python module generated from Java source file java.nio.file.attribute.FileAttribute

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.file.attribute import *
from typing import Any, Callable, Iterable, Tuple


class FileAttribute:

    def name(self) -> str:
        """
        Returns the attribute name.

        Returns
        - The attribute name
        """
        ...


    def value(self) -> "T":
        """
        Returns the attribute value.

        Returns
        - The attribute value
        """
        ...
