"""
Python module generated from Java source file com.google.common.collect.RegularImmutableTable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.j2objc.annotations import WeakOuter
from java.util import Collections
from java.util import Comparator
from java.util import LinkedHashSet
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class RegularImmutableTable(ImmutableTable):
    """
    An implementation of ImmutableTable holding an arbitrary number of cells.

    Author(s)
    - Gregory Kick
    """


