"""
Python module generated from Java source file com.google.common.collect.TableCollectors

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.common.collect.Tables import AbstractCell
from java.util.function import BinaryOperator
from java.util.function import Function
from java.util.function import Supplier
from java.util.stream import Collector
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class TableCollectors:
    """
    Collectors utilities for `common.collect.Table` internals.
    """


