"""
Python module generated from Java source file org.bukkit.Utility

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Utility:
    """
    This annotation indicates a method (and sometimes constructor) will chain
    its internal operations.
    
    This is solely meant for identifying methods that don't need to be
    overridden / handled manually.
    """


