"""
Python module generated from Java source file org.yaml.snakeyaml.emitter.EmitterException

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.emitter import *
from org.yaml.snakeyaml.error import YAMLException
from typing import Any, Callable, Iterable, Tuple


class EmitterException(YAMLException):
    """
    For emitter
    """

    def __init__(self, msg: str):
        """
        Create

        Arguments
        - msg: - text to show
        """
        ...
