"""
Python module generated from Java source file org.bukkit.plugin.AuthorNagException

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class AuthorNagException(RuntimeException):

    def __init__(self, message: str):
        """
        Constructs a new AuthorNagException based on the given Exception

        Arguments
        - message: Brief message explaining the cause of the exception
        """
        ...


    def getMessage(self) -> str:
        ...
