"""
Python module generated from Java source file com.google.common.reflect.TypeCapture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.reflect import *
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Type
from typing import Any, Callable, Iterable, Tuple


class TypeCapture:
    """
    Captures the actual type of `T`.

    Author(s)
    - Ben Yu
    """


