"""
Python module generated from Java source file org.bukkit.util.NumberConversions

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class NumberConversions:
    """
    Utils for casting number types to other number types
    """

    @staticmethod
    def floor(num: float) -> int:
        ...


    @staticmethod
    def ceil(num: float) -> int:
        ...


    @staticmethod
    def round(num: float) -> int:
        ...


    @staticmethod
    def square(num: float) -> float:
        ...


    @staticmethod
    def toInt(object: "Object") -> int:
        ...


    @staticmethod
    def toFloat(object: "Object") -> float:
        ...


    @staticmethod
    def toDouble(object: "Object") -> float:
        ...


    @staticmethod
    def toLong(object: "Object") -> int:
        ...


    @staticmethod
    def toShort(object: "Object") -> int:
        ...


    @staticmethod
    def toByte(object: "Object") -> int:
        ...


    @staticmethod
    def isFinite(d: float) -> bool:
        ...


    @staticmethod
    def isFinite(f: float) -> bool:
        ...


    @staticmethod
    def checkFinite(d: float, message: str) -> None:
        ...


    @staticmethod
    def checkFinite(d: float, message: str) -> None:
        ...
