"""
Python module generated from Java source file org.bukkit.block.Lidded

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Lidded:

    def open(self) -> None:
        """
        Sets the block's animated state to open and prevents it from being closed
        until .close() is called.
        """
        ...


    def close(self) -> None:
        """
        Sets the block's animated state to closed even if a player is currently
        viewing this block.
        """
        ...
