"""
Python module generated from Java source file org.bukkit.Translatable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Translatable:
    """
    Represents an object with a text representation that can be translated by the
    Minecraft client.
    """

    def getTranslationKey(self) -> str:
        """
        Get the translation key, suitable for use in a translation component.

        Returns
        - the translation key
        """
        ...
