"""
Python module generated from Java source file com.google.common.collect.Platform

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.util import Arrays
from java.util.concurrent import ConcurrentHashMap
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Platform:
    """
    Methods factored out so that they can be emulated differently in GWT.

    Author(s)
    - Hayward Chan
    """


