"""
Python module generated from Java source file com.google.common.collect.ConsumingQueueIterator

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import Queue
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ConsumingQueueIterator(AbstractIterator):
    """
    An Iterator implementation which draws elements from a queue, removing them from the queue as it
    iterates. This class is not thread safe.
    """


