"""
Python module generated from Java source file org.bukkit.map.MinecraftFont

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.map import *
from typing import Any, Callable, Iterable, Tuple


class MinecraftFont(MapFont):
    """
    Represents the built-in Minecraft font.
    """

    Font = MinecraftFont(false)
    """
    A static non-malleable MinecraftFont.
    """


    def __init__(self):
        """
        Initialize a new MinecraftFont.
        """
        ...
