"""
Python module generated from Java source file org.bukkit.conversations.NumericPrompt

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.apache.commons.lang3.math import NumberUtils
from org.bukkit.conversations import *
from typing import Any, Callable, Iterable, Tuple


class NumericPrompt(ValidatingPrompt):
    """
    NumericPrompt is the base class for any prompt that requires a Number response from the user.
    """

    def __init__(self):
        ...
