"""
Python module generated from Java source file org.bukkit.entity.Boss

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.boss import BossBar
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Boss(Entity):
    """
    Represents the Boss Entity.
    """

    def getBossBar(self) -> "BossBar":
        """
        Returns the BossBar of the Boss

        Returns
        - the BossBar of the entity
        """
        ...
