"""
Python module generated from Java source file java.util.IllegalFormatException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class IllegalFormatException(IllegalArgumentException):
    """
    Unchecked exception thrown when a format string contains an illegal syntax
    or a format specifier that is incompatible with the given arguments.  Only
    explicit subtypes of this exception which correspond to specific errors
    should be instantiated.

    Since
    - 1.5
    """


