"""
Python module generated from Java source file com.google.common.reflect.Types

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Joiner
from com.google.common.base import Objects
from com.google.common.base import Predicates
from com.google.common.collect import ImmutableList
from com.google.common.collect import ImmutableMap
from com.google.common.collect import Iterables
from com.google.common.reflect import *
from java.io import Serializable
from java.lang.reflect import AnnotatedElement
from java.lang.reflect import Array
from java.lang.reflect import GenericArrayType
from java.lang.reflect import GenericDeclaration
from java.lang.reflect import InvocationHandler
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Proxy
from java.lang.reflect import Type
from java.lang.reflect import TypeVariable
from java.lang.reflect import WildcardType
from java.security import AccessControlException
from java.util import Arrays
from java.util.concurrent.atomic import AtomicReference
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Types:
    """
    Utilities for working with Type.

    Author(s)
    - Ben Yu
    """


