"""
Python module generated from Java source file org.bukkit.material.Redstone

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Redstone:
    """
    Indicated a Material that may carry or create a Redstone current
    """

    def isPowered(self) -> bool:
        """
        Gets the current state of this Material, indicating if it's powered or
        unpowered

        Returns
        - True if powered, otherwise False
        """
        ...
