"""
Python module generated from Java source file org.yaml.snakeyaml.tokens.TagTuple

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.tokens import *
from typing import Any, Callable, Iterable, Tuple


class TagTuple:

    def __init__(self, handle: str, suffix: str):
        ...


    def getHandle(self) -> str:
        ...


    def getSuffix(self) -> str:
        ...
