"""
Python module generated from Java source file com.google.common.cache.IgnoreJRERequirement

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.cache import *
from typing import Any, Callable, Iterable, Tuple


class IgnoreJRERequirement:
    """
    Disables Animal Sniffer's checking of compatibility with older versions of Java/Android.
    
    Each package's copy of this annotation needs to be listed in our `pom.xml`.
    """


