"""
Python module generated from Java source file java.util.ServiceConfigurationError

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class ServiceConfigurationError(Error):

    def __init__(self, msg: str):
        """
        Constructs a new instance with the specified message.

        Arguments
        - msg: The message, or `null` if there is no message
        """
        ...


    def __init__(self, msg: str, cause: "Throwable"):
        """
        Constructs a new instance with the specified message and cause.

        Arguments
        - msg: The message, or `null` if there is no message
        - cause: The cause, or `null` if the cause is nonexistent
                       or unknown
        """
        ...
