"""
Python module generated from Java source file org.bukkit.util.CachedServerIcon

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Server
from org.bukkit.event.server import ServerListPingEvent
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class CachedServerIcon:
    """
    This is a cached version of a server-icon. It's internal representation
    and implementation is undefined.

    See
    - ServerListPingEvent.setServerIcon(CachedServerIcon)
    """


