"""
Python module generated from Java source file com.google.gson.internal.GsonBuildConfig

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from typing import Any, Callable, Iterable, Tuple


class GsonBuildConfig:
    """
    Build configuration for Gson. This file is automatically populated by templating-maven-plugin and
    .java/.class files are generated for use in Gson.

    Author(s)
    - Inderjeet Singh
    """

    VERSION = "2.11.0"
    """
    This field is automatically populated by Maven when a build is triggered
    """
