"""
Python module generated from Java source file org.yaml.snakeyaml.emitter.EmitterState

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from org.yaml.snakeyaml.emitter import *
from typing import Any, Callable, Iterable, Tuple


class EmitterState:
    """
    Python's methods are first class object. Java needs a class.
    """

    def expect(self) -> None:
        ...
