"""
Python module generated from Java source file org.bukkit.event.vehicle.VehicleMoveEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import Vehicle
from org.bukkit.event import HandlerList
from org.bukkit.event.vehicle import *
from typing import Any, Callable, Iterable, Tuple


class VehicleMoveEvent(VehicleEvent):
    """
    Raised when a vehicle moves.
    """

    def __init__(self, vehicle: "Vehicle", from: "Location", to: "Location"):
        ...


    def getFrom(self) -> "Location":
        """
        Get the previous position.

        Returns
        - Old position.
        """
        ...


    def getTo(self) -> "Location":
        """
        Get the next position.

        Returns
        - New position.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...
