"""
Python module generated from Java source file com.google.common.collect.ForwardingImmutableCollection

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class ForwardingImmutableCollection:
    """
    Dummy class that makes the GWT serialization policy happy. It isn't used on the server-side.

    Author(s)
    - Hayward Chan
    """


