"""
Python module generated from Java source file com.google.common.collect.GwtTransient

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class GwtTransient:
    """
    Private replacement for com.google.gwt.user.client.rpc.GwtTransient to work around
    build-system quirks. This annotation should be used **only** in `com.google.common.collect`.
    """


