"""
Python module generated from Java source file com.google.common.primitives.ShortsMethodsForWeb

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from typing import Any, Callable, Iterable, Tuple


class ShortsMethodsForWeb:
    """
    Holder for web specializations of methods of `Shorts`. Intended to be empty for regular
    version.
    """


