"""
Python module generated from Java source file com.google.gson.internal.TroubleshootingGuide

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from typing import Any, Callable, Iterable, Tuple


class TroubleshootingGuide:

    @staticmethod
    def createUrl(id: str) -> str:
        """
        Creates a URL referring to the specified troubleshooting section.
        """
        ...
