"""
Python module generated from Java source file com.google.common.collect.ArrayListMultimapGwtSerializationDependencies

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class ArrayListMultimapGwtSerializationDependencies(AbstractListMultimap):
    """
    A dummy superclass to support GWT serialization of the element types of an ArrayListMultimap. The GWT supersource for this class contains a field for each type.
    
    For details about this hack, see `GwtSerializationDependencies`, which takes the same
    approach but with a subclass rather than a superclass.
    
    TODO(cpovirk): Consider applying this subclass approach to our other types.
    """


