"""
Python module generated from Java source file org.bukkit.event.world.SpawnChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit import World
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class SpawnChangeEvent(WorldEvent):
    """
    An event that is called when a world's spawn changes. The world's previous
    spawn location is included.
    """

    def __init__(self, world: "World", previousLocation: "Location"):
        ...


    def getPreviousLocation(self) -> "Location":
        """
        Gets the previous spawn location

        Returns
        - Location that used to be spawn
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...
