"""
Python module generated from Java source file com.google.gson.stream.JsonScope

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.stream import *
from typing import Any, Callable, Iterable, Tuple


class JsonScope:
    """
    Lexical scoping elements within a JSON reader or writer.

    Author(s)
    - Jesse Wilson

    Since
    - 1.6
    """


