"""
Python module generated from Java source file org.bukkit.util.io.Wrapper

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableMap
from java.io import Serializable
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import ConfigurationSerialization
from org.bukkit.util.io import *
from typing import Any, Callable, Iterable, Tuple


class Wrapper(Serializable):


