"""
Python module generated from Java source file org.bukkit.material.Diode

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Diode(MaterialData, Directional, Redstone):
    """
    Represents a diode/repeater in the on or off state, with a delay and facing
    in a specific direction.

    See
    - Material.LEGACY_DIODE_BLOCK_ON

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        """
        Constructs a diode switched on, with a delay of 1 and facing the default
        direction (north).
        
        By default this constructor creates a diode that is switched on for
        backwards compatibility with past implementations.
        """
        ...


    def __init__(self, facingDirection: "BlockFace"):
        """
        Constructs a diode switched off, with a delay of 1 and facing the
        specified direction.

        Arguments
        - facingDirection: the direction the diode is facing

        See
        - BlockFace
        """
        ...


    def __init__(self, facingDirection: "BlockFace", delay: int):
        """
        Constructs a diode switched off, with the specified delay and facing the
        specified direction.

        Arguments
        - facingDirection: the direction the diode is facing
        - delay: The number of ticks (1-4) before the diode turns on after
        being powered

        See
        - BlockFace
        """
        ...


    def __init__(self, facingDirection: "BlockFace", delay: int, state: bool):
        """
        Constructs a diode switched on or off, with the specified delay and
        facing the specified direction.

        Arguments
        - facingDirection: the direction the diode is facing
        - delay: The number of ticks (1-4) before the diode turns on after
        being powered
        - state: True if the diode is in the on state

        See
        - BlockFace
        """
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def setDelay(self, delay: int) -> None:
        """
        Sets the delay of the repeater.

        Arguments
        - delay: The new delay (1-4)
        """
        ...


    def getDelay(self) -> int:
        """
        Gets the delay of the repeater in ticks.

        Returns
        - The delay (1-4)
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        """
        Sets the direction this diode is facing.

        Arguments
        - face: The direction to set this diode to

        See
        - BlockFace
        """
        ...


    def getFacing(self) -> "BlockFace":
        """
        Gets the direction this diode is facing

        Returns
        - The direction this diode is facing

        See
        - BlockFace
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Diode":
        ...


    def isPowered(self) -> bool:
        """
        Checks if the diode is powered.

        Returns
        - True if the diode is powered
        """
        ...
