"""
Python module generated from Java source file org.bukkit.generator.structure.StructurePiece

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.generator.structure import *
from org.bukkit.util import BoundingBox
from typing import Any, Callable, Iterable, Tuple


class StructurePiece:
    """
    Represents an individual part of a GeneratedStructure.

    See
    - GeneratedStructure
    """

    def getBoundingBox(self) -> "BoundingBox":
        """
        Gets the bounding box of this structure piece.

        Returns
        - bounding box of this structure piece
        """
        ...
