"""
Python module generated from Java source file com.google.common.collect.CollectSpliterators

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.j2objc.annotations import Weak
from java.util import Comparator
from java.util import Spliterator
from java.util.function import Consumer
from java.util.function import DoubleConsumer
from java.util.function import Function
from java.util.function import IntConsumer
from java.util.function import IntFunction
from java.util.function import LongConsumer
from java.util.function import Predicate
from java.util.stream import IntStream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CollectSpliterators:
    """
    Spliterator utilities for `common.collect` internals.
    """


