"""
Python module generated from Java source file com.google.common.math.ToDoubleRounder

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.math import *
from java.math import RoundingMode
from typing import Any, Callable, Iterable, Tuple


class ToDoubleRounder:
    """
    Helper type to implement rounding `X` to a representable `double` value according to
    a RoundingMode.
    """


