"""
Python module generated from Java source file org.bukkit.event.server.RemoteServerCommandEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import CommandSender
from org.bukkit.event import HandlerList
from org.bukkit.event.server import *
from typing import Any, Callable, Iterable, Tuple


class RemoteServerCommandEvent(ServerCommandEvent):
    """
    This event is called when a command is received over RCON. See the javadocs
    of ServerCommandEvent for more information.
    """

    def __init__(self, sender: "CommandSender", command: str):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...
